@@ -3,30 +3,9 @@ from __future__ import absolute_import, print_function, unicode_literals
 
 from django.conf import settings
 from django.test import TestCase
-from django.test.client import Client as TestClient
 from django.utils import translation
 
-
-class TranslationSafeTestClient(TestClient):
-    """TestClient subclass which preserves the active language
-
-    Django's LocaleMiddleware deactivates the current language at the end
-    of each request, which resets it to the default. This is fine in normal
-    operation but annoying if your unit tests want to confirm that translated
-    text was present in the response as _(foo) will return the system default
-    language if you call it after making a request using the test client
-    """
-
-    def request(self, *args, **kwargs):
-        active_lang = translation.get_language()
-
-        if active_lang is not None:
-            kwargs['HTTP_ACCEPT_LANGUAGE'] = active_lang
-
-        try:
-            return super(TranslationSafeTestClient, self).request(*args, **kwargs)
-        finally:
-            translation.activate(active_lang)
+from .testclients import TranslationSafeTestClient
 
 
 class LocalizedTestCaseMetaclass(type):
@@ -47,7 +26,7 @@ class LocalizedTestCaseMetaclass(type):
                 trans_name = '%s_%s' % (method_name, lang)
                 decorated_f = meta.activate_language(lang, method)
                 # nose magic: see http://stackoverflow.com/questions/5176396/
-                decorated_f.__name__ = trans_name
+                decorated_f.__name__ = str(trans_name)
                 class_dict[trans_name] = decorated_f
 
         return type.__new__(meta, class_name, base_classes, class_dict)
